"use strict";
/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2023 Savoir-faire Linux. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bitBakeProjectScannerClient = exports.BitBakeProjectScannerClient = void 0;
const BitbakeScanResult_1 = require("./lib/src/types/BitbakeScanResult");
const events_1 = __importDefault(require("events"));
const OutputLogger_1 = require("./lib/src/utils/OutputLogger");
/// Keeps track of the bitbake scan results from the language server
class BitBakeProjectScannerClient {
    constructor() {
        this.bitbakeScanResult = {
            _layers: [],
            _classes: [],
            _includes: [],
            _recipes: [],
            _overrides: [],
            _confFiles: [],
            _workspaces: []
        };
        this.onChange = new events_1.default();
    }
    setConnection(connection) {
        this.connection = connection;
    }
    buildHandlers() {
        return this.bitbakeScanHandler();
    }
    bitbakeScanHandler() {
        if (this.connection === undefined) {
            throw new Error('BitBakeProjectScannerClient: connection is undefined');
        }
        const subscriptions = [];
        subscriptions.push(this.connection.onNotification('bitbake/scanReady', (scanResults) => {
            // In case a parsing error was just introduce, we keep the previous results to keep navigation functional
            if (!(0, BitbakeScanResult_1.scanContainsRecipes)(this.bitbakeScanResult) || (0, BitbakeScanResult_1.scanContainsRecipes)(scanResults)) {
                this.bitbakeScanResult = scanResults;
            }
            this.onChange.emit('scanReady', scanResults);
            OutputLogger_1.logger.info('Bitbake scan results received from language server');
        }));
        return subscriptions;
    }
}
exports.BitBakeProjectScannerClient = BitBakeProjectScannerClient;
exports.bitBakeProjectScannerClient = new BitBakeProjectScannerClient();
//# sourceMappingURL=BitbakeProjectScannerClient.js.map