"use strict";
/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2023 Savoir-faire Linux. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = exports.OutputLogger = void 0;
class OutputLogger {
    constructor() {
        // default value in package.json
        this.level = '';
    }
    static getInstance() {
        if (OutputLogger.instance === undefined) {
            OutputLogger.instance = new OutputLogger();
        }
        return OutputLogger.instance;
    }
    log(message, level = 'info') {
        if (this.shouldLog(level)) {
            this.outputChannel?.appendLine(message);
            const time = new Date().toISOString().substring(11, 23);
            console.log(`${time} [${level[0].toUpperCase() + level.slice(1)}] ${message}`);
        }
    }
    info(message) {
        this.log(message);
    }
    debug(message) {
        this.log(message, 'debug');
    }
    warn(message) {
        this.log(message, 'warning');
    }
    error(message) {
        this.log(message, 'error');
    }
    clear() {
        console.clear();
        this.outputChannel?.clear();
    }
    shouldLog(level) {
        // Determine if the log level should be printed
        const logLevels = ['none', 'error', 'warning', 'info', 'debug'];
        const currentLevelIndex = logLevels.indexOf(this.level);
        const messageLevelIndex = logLevels.indexOf(level);
        return currentLevelIndex >= messageLevelIndex;
    }
}
exports.OutputLogger = OutputLogger;
// Create and export the singleton logger instance
exports.logger = OutputLogger.getInstance();
//# sourceMappingURL=OutputLogger.js.map